@@ -7,6 +7,7 @@
 #' @param AOIs A dataframe of areas of interest (AOIs), with one row per AOI (x, y, width_radius, height).
 #' @param AOI_names An optional vector of AOI names to replace the default "AOI_1", "AOI_2", etc.
 #' @param participant_ID the variable that determines the participant identifier. If no column present, assumes a single participant
+#' @param progress Display a progress bar
 #' @return a dataframe containing the sequence of entries into AOIs on each trial, entry/exit/duration time into AOI
 #' @export
 #'
@@ -18,10 +19,10 @@
 #' AOI_seq(fix_d, AOIs = HCL_AOIs, participant_ID = "pNum")
 #' }
 #'
+#' @import pbapply
 #' @importFrom stats setNames complete.cases
-#' @importFrom utils stack
 
-AOI_seq <- function(data, AOIs, AOI_names = NULL, participant_ID = "participant_ID") {
+AOI_seq <- function(data, AOIs, AOI_names = NULL, participant_ID = "participant_ID", progress = TRUE) {
 
   if(is.null(data[["fix_n"]])) stop("column 'fix_n' not detected. Are you sure this is fixation data from eyetools?")
 
@@ -52,7 +53,7 @@ AOI_seq <- function(data, AOIs, AOI_names = NULL, participant_ID = "participant_
   }
 
   data <- split(data, data[[participant_ID]])
-  out <- lapply(data, internal_AOI_seq, AOIs, AOI_names)
+  if(progress) out <- pblapply(data, internal_AOI_seq, AOIs, AOI_names) else out <- lapply(data, internal_AOI_seq, AOIs, AOI_names)
   out <- do.call("rbind.data.frame", out)
   rownames(out) <- NULL
   out <- .check_ppt_n_out(out)
@@ -64,7 +65,7 @@ AOI_seq <- function(data, AOIs, AOI_names = NULL, participant_ID = "participant_
 AOI_seq_trial_process <- function(trial_data, AOIs, AOI_names, participant_ID) {
 
   trial_val <- trial_data$trial[[1]]
-  ppt_val <- trial_data[['participant_ID']][[1]]
+  ppt_val <- trial_data[[participant_ID]][[1]]
 
   trial_data <- trial_data[complete.cases(trial_data),] # remove any NAs (i.e., in raw data)
 
@@ -88,6 +89,7 @@ AOI_seq_trial_process <- function(trial_data, AOIs, AOI_names, participant_ID) {
 
   # check if trial has no fixations on any AOIs
   if (sum(aoi_entries)==0) {
+
     # if no data, return a trial result with NAs
     aoi_trial_out <- data.frame(participant_ID = ppt_val,
                                 trial = trial_val,
